@@ -120,6 +120,9 @@ typedef struct {
     uint8_t  bdplus_gen;          /* BD+ content code generation */
     uint32_t bdplus_date;         /* BD+ content code relese date ((year<<16)|(month<<8)|day) */
 
+    /* disc application info (libbluray > 1.2.0) */
+    uint8_t initial_dynamic_range_type; /* bd_dynamic_range_type_e */
+
 } BLURAY_DISC_INFO;
 
 /*
@@ -212,6 +215,12 @@ typedef enum {
     BLURAY_MARK_LINK      = 0x02,  /* link point */
 } bd_mark_type_e;
 
+typedef enum {
+    BLURAY_DYNAMIC_RANGE_SDR          = 0,
+    BLURAY_DYNAMIC_RANGE_HDR10        = 1,
+    BLURAY_DYNAMIC_RANGE_DOLBY_VISION = 2
+} bd_dynamic_range_type_e;
+
 typedef struct bd_stream_info {
     uint8_t     coding_type;
     uint8_t     format;
@@ -684,6 +693,7 @@ typedef enum {
 
     BLURAY_PLAYER_PERSISTENT_ROOT            = 0x200, /* Root path to the BD_J persistent storage location. String. */
     BLURAY_PLAYER_CACHE_ROOT                 = 0x201, /* Root path to the BD_J cache storage location. String. */
+    BLURAY_PLAYER_JAVA_HOME                  = 0x202, /* Location of JRE. String. Default: NULL (autodetect). */
 } bd_player_setting;
 
 /**
@@ -841,6 +851,7 @@ typedef struct {
  */
 int  bd_get_event(BLURAY *bd, BD_EVENT *event);
 
+const char *bd_event_name(uint32_t /* bd_event_e */ event);
 
 /*
  * On-screen display
